package jnormaliz;

import java.io.File;

/**
 * Class to hold parameters to be used in a Normaliz execution
 */
public class NormalizConfig {

    /**
     * Holds the input file to be used in computations
     */
    public File inFile = null;

    /**
     * Returns the full path for the input file without the .in extension
     */
    public String getInFileWithoutExt() {
        return FileUtils.stripInExtension(inFile.getAbsolutePath());
    }

    /**
     * Options of integer precision that can be used when running Normaliz
     */
    public enum Precision {

        PRECISION64, PRECISIONBIG
    };

    /**
     * Specifies integer precision to be used
     */
    public Precision precision;

    /**
     * Computation types that can be used when running Normaliz
     */
    public enum ComputationType {

        SUPPORT_HYPERPLANES, TRIANGULATION,
        VOLUME, HILBERT_BASIS_VOLUME, HILBERT_BASIS,
        DEGREE_1_ELEMENTS, HILBERT_SERIES,
        HILBERT_BASIS_SERIES, DUAL
    };

    /**
     * Specifies computation type to be used
     */
    public ComputationType computationType;

    /**
     * Amount of output that can be produced by Normaliz
     */
    public enum OutputFiles {

        ONLY_OUT, SOME, ALL
    };

    /**
     * Specifies output files to be generated
     */
    public OutputFiles outputFiles;

    /**
     * Specifies whether or not to save memory while running Normaliz
     */
   // public boolean saveMemory; // option for Normliz version 2.1, 2.2

    /**
     * Specifies whether or not to check for arithmetic overflow while
     * running Normaliz
     */
    public boolean testArithmeticOverflow;

     /**
     * Specifies whether or not to control the maximal number of paralell
     * threads generated by Normaliz
     */
    public boolean writeTriangulationFile;

     /**
     * Specifies whether or not to write the triangulation file generated 
     * by Normaliz
     */
    public boolean controlParalellization;

     /**
     * Specifies the maximum number of parallel threads generated by Normaliz
     */
    public Integer numberParallelThreads;
}
